@@ -80,6 +80,7 @@ class adrv9009_zu11eg_multi(object):
         self._clk_chip_show_cap_bank_sel = False
         self._resync_tx = False
         self._rx_initialized = False
+        self._request_sysref_carrier = False
         self.fmcomms8 = fmcomms8
         if fmcomms8:
             self.primary = adrv9009_zu11eg_fmcomms8(
@@ -208,7 +209,7 @@ class adrv9009_zu11eg_multi(object):
         if (state_last == 1) and (paused == 0):
             return "done"
 
-        return "undef"
+        assert False
 
     def __jesd204_fsm_is_done(self):
         cnt = 0
@@ -227,6 +228,12 @@ class adrv9009_zu11eg_multi(object):
 
             for index, dev in enumerate(self.secondaries + [self.primary]):
                 ret = self._device_is_running(dev, index, self._jesd_fsm_show_status)
+                if index == 0:
+                    statep = dev.jesd204_fsm_state
+                else:
+                    state = dev.jesd204_fsm_state
+                    assert state == statep
+
                 if ret == "paused":
                     dev.jesd204_fsm_resume = "1"
 
@@ -350,7 +357,10 @@ class adrv9009_zu11eg_multi(object):
 
     def sysref_request(self):
         """ sysref_request: Sysref request for parent HMC7044 """
-        self.primary._clock_chip_ext.attrs["sysref_request"].value = "1"
+        if self._request_sysref_carrier:
+            self.primary._clock_chip_carrier.attrs["sysref_request"].value = "1"
+        else:
+            self.primary._clock_chip_ext.attrs["sysref_request"].value = "1"
 
     def set_trx_lo_frequency(self, freq):
         """ set_trx_lo_frequency:
@@ -364,12 +374,13 @@ class adrv9009_zu11eg_multi(object):
             dev._set_iio_debug_attr_str(
                 "adi,trx-pll-lo-frequency_hz", freq, dev._ctrl_b
             )
-            dev._set_iio_debug_attr_str(
-                "adi,trx-pll-lo-frequency_hz", freq, dev._ctrl_c
-            )
-            dev._set_iio_debug_attr_str(
-                "adi,trx-pll-lo-frequency_hz", freq, dev._ctrl_d
-            )
+            if self.fmcomms8:
+                dev._set_iio_debug_attr_str(
+                    "adi,trx-pll-lo-frequency_hz", freq, dev._ctrl_c
+                )
+                dev._set_iio_debug_attr_str(
+                    "adi,trx-pll-lo-frequency_hz", freq, dev._ctrl_d
+                )
 
     def __refill_samples(self, dev, is_primary):
         if is_primary:
@@ -408,7 +419,7 @@ class adrv9009_zu11eg_multi(object):
             except:  # noqa: E722
                 print("Re-initializing due to lock-up")
                 self.reinitialize()
-            raise Exception("Unable to initialize (Board reboot required)")
+        raise Exception("Unable to initialize (Board reboot required)")
 
     def rx(self):
         """ Receive data from multiple hardware buffers for each channel index in
